part of tecfy_basic_package;

class TecfyHeader {
  final TecfyHeaderType type;
  final double? scaleX;
  final double? scaleY;
  final Offset? offset;
  final Widget? child;
  final bool? floating;
  final bool? pinned;
  final Widget? ShrunkChild;

  /// builder function taking a progress number on the parameter,
  /// progress value starts from 1 and move to 0 when it's totally shrunk
  final Widget Function(double)? builder;
  final Alignment? alignment;
  final double maxHeight;
  final double minHeight;
  final double elevation;
  final Color? color;
  final SliverPersistentHeaderDelegate delegate;
  TecfyHeader.builder({
    Key? key,
    required this.builder,
    this.floating,
    this.pinned,
    this.color,
    required this.maxHeight,
    required this.minHeight,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.feedOut,
        scaleX = null,
        scaleY = null,
        offset = null,
        child = null,
        ShrunkChild = null,
        alignment = null,
        delegate = BuilderDelegate(
          builder: builder!,
          elevation: elevation,
          color: color,
          minHeight: minHeight,
          maxHeight: maxHeight,
        );
  TecfyHeader.fixed({
    Key? key,
    required this.child,
    this.floating,
    this.pinned,
    this.color,
    required double height,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.feedOut,
        scaleX = null,
        scaleY = null,
        offset = null,
        ShrunkChild = null,
        minHeight = height,
        maxHeight = height,
        alignment = null,
        builder = null,
        delegate = FixedDelegate(
          child: child!,
          height: height,
          color: color,
          elevation: elevation,
        );
  TecfyHeader.feedOut({
    Key? key,
    required this.child,
    this.floating,
    this.pinned,
    this.color,
    required double height,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.feedOut,
        scaleX = null,
        scaleY = null,
        offset = null,
        builder = null,
        ShrunkChild = null,
        minHeight = height,
        maxHeight = height,
        alignment = null,
        delegate = FadeOutDelegate(
          child: child!,
          height: height,
          elevation: elevation,
          color: color,
        );

  TecfyHeader.transform({
    Key? key,
    required this.child,
    required this.ShrunkChild,
    this.floating,
    this.pinned,
    this.color,
    required double expandedHeight,
    required double ShrunkHeight,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.transform,
        builder = null,
        scaleX = null,
        scaleY = null,
        offset = null,
        minHeight = expandedHeight,
        maxHeight = ShrunkHeight,
        alignment = null,
        delegate = TransformDelegate(
          child: child!,
          shrinkChild: ShrunkChild!,
          expandedHeight: expandedHeight,
          ShrunkHeight: ShrunkHeight,
          color: color,
          elevation: elevation,
        );

  TecfyHeader.scale({
    Key? key,
    required this.scaleX,
    required this.scaleY,
    required this.child,
    this.alignment = Alignment.topLeft,
    required this.maxHeight,
    required this.minHeight,
    this.floating,
    this.pinned,
    this.color,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.scale,
        builder = null,
        offset = null,
        ShrunkChild = null,
        delegate = ScaleDelegate(
          elevation: elevation,
          child: child!,
          scaleX: scaleX!,
          scaleY: scaleY!,
          alignment: alignment!,
          maxHeight: maxHeight,
          minHeight: minHeight,
          color: color,
        );

  TecfyHeader.transition({
    Key? key,
    required this.offset,
    required this.child,
    required this.maxHeight,
    required this.minHeight,
    this.floating,
    this.pinned,
    this.color,
    this.elevation = 0.0,
  })  : type = TecfyHeaderType.transition,
        builder = null,
        scaleX = null,
        scaleY = null,
        ShrunkChild = null,
        alignment = null,
        delegate = TransitionDelegate(
            child: child!, offset: offset!, color: color, elevation: elevation);
}

enum TecfyHeaderType { fixed, feedOut, transition, scale, transform }
